@@ -4,8 +4,14 @@ from pathlib import Path
 import os
 from tkinter import ttk
 from time import sleep
-from ghettorecorder.lib.edit import UItextEditor
-from ghettorecorder.lib import term
+
+try:
+    from ghettorecorder.lib.edit import UItextEditor
+    from ghettorecorder.lib import term
+except ImportError:
+    from lib.edit import UItextEditor
+    from lib import term
+
 try:
     import tkinter as tk
 except ImportError:
@@ -15,34 +21,37 @@ try:
 except ImportError:
     print(f'\n error tkinter.filedialog import askdirectory, askopenfilename\n')
 
+
 # logging.basicConfig(level=logging.DEBUG, format='(%(threadName)-10s) %(message)s',)
 
 
 class UIWindow(tk.Tk):
-
     box_list = []
     search_list = []
     entry_list = []
     lbl_li = []
 
     timer_val = ['', 1, 2, 4, 6, 12, 24]
+    language_list = ['eng', 'deutsch']
     data_dir_set = False
     record_started = False
     search_started = False
+    start_screen = True
 
     def __init__(self, radio_dir=None, settings_path=None):
         super().__init__()
-        self.gr_version = '0.1.3'
+        self.list_e = []
+        self.gr_version = '0.6.5'
         self.radio_dir = radio_dir
         self.settings_path = settings_path
 
         self.title(f"Ghetto Recorder {self.gr_version} Concrete IT (by René Horn)")
-        self.geometry('{}x{}'.format(620, 460))
+        self.geometry('{}x{}'.format(700, 510))
 
         # main containers create
-        self.top_frame = tk.Frame(master=self, bg='azure3', width=620, height=50, pady=3)
-        self.center = tk.Frame(master=self, bg='white', width=620, height=360, padx=3, pady=3)
-        self.btm_frame = tk.Frame(master=self, bg='azure3', width=620, height=50, pady=3)
+        self.top_frame = tk.Frame(master=self, bg='azure3', width=700, height=50, pady=3)
+        self.center = tk.Frame(master=self, bg='white', width=700, height=410, padx=3, pady=3)
+        self.btm_frame = tk.Frame(master=self, bg='azure3', width=700, height=50, pady=3)
 
         # main containers layout
         self.grid_rowconfigure(1, weight=1)
@@ -57,9 +66,10 @@ class UIWindow(tk.Tk):
         self.center.grid_columnconfigure(1, weight=1)
 
         self.ctr_left = tk.Frame(self.center, bg='blue', width=25, height=360)
-        self.canvas = tk.Canvas(self.center, bg='cornflowerblue', width=570, height=360, bd=0)
-        self.ctr_mid = tk.Frame(self.center, bg='azure3', width=570, height=360, padx=3, pady=3)
-        self.ctr_right = tk.Frame(self.center, bg='green', width=25, height=360, padx=3, pady=3)
+        self.canvas = tk.Canvas(self.center, bg='cornflowerblue', width=570, height=410, bd=0)
+        self.ctr_mid = tk.Frame(self.center, bg='azure3', width=570, height=410, padx=3, pady=3)
+        self.ctr_right = tk.Frame(self.center, bg='green', width=25, height=410, padx=3, pady=3)
+        self.progressbar = ttk.Progressbar(self.ctr_right, orient="vertical", length=400, mode="determinate")  # -10 ok
         # center grid
         self.ctr_left.grid(row=0, column=0, sticky="ns")
         self.canvas.grid(row=0, column=1, sticky="nsew")
@@ -75,10 +85,12 @@ class UIWindow(tk.Tk):
         self.btn_browse = tk.Button(self.top_frame, text="Save to ...", width=10, command=self.browse_dir_button)
         self.lbl_timer = tk.Label(self.top_frame, text='Timer', bg='azure3', anchor="s")
         self.combo_timer = ttk.Combobox(self.top_frame, state="readonly", width=5, values=self.timer_val)
+        self.lbl_lang = tk.Label(self.top_frame, text='Language', bg='azure3', anchor="s")
+        self.combo_lang = ttk.Combobox(self.top_frame, state="readonly", width=5, values=self.language_list)
 
         self.entry_ini = tk.Entry(self.top_frame, background="white", borderwidth=1, relief=tk.FLAT, width=70)
         self.entry_ini.insert(0, ' Path to settings.ini')
-        self.entry_bbr = tk.Entry(self.top_frame, background="white",  borderwidth=1, relief=tk.FLAT, width=70)
+        self.entry_bbr = tk.Entry(self.top_frame, background="white", borderwidth=1, relief=tk.FLAT, width=70)
         self.entry_bbr.insert(0, ' place to create a bunch of folders')
 
         # upper frame layout
@@ -87,14 +99,17 @@ class UIWindow(tk.Tk):
         self.btn_ini.grid(row=0, column=1, padx=2, pady=2, sticky='w')
         self.entry_ini.grid(row=0, column=2, columnspan=3, padx=5, sticky='e')
         self.lbl_timer.grid(row=0, column=5, padx=10, sticky="s")
+        self.lbl_lang.grid(row=0, column=6, padx=10, sticky="s")
 
         self.lbl_browse.grid(row=1, column=0, padx=2, pady=2, sticky="w")
         self.btn_browse.grid(row=1, column=1, padx=2, sticky='w')
         self.entry_bbr.grid(row=1, column=2, columnspan=3, padx=5, sticky='e')
         self.combo_timer.grid(row=1, column=5, padx=10, sticky='e')
+        self.combo_lang.grid(row=1, column=6, padx=10, sticky='e')
+        self.combo_lang.current(0)
 
         # Middle
-        self.ghetto_canvas = tk.Canvas(self.ctr_mid, width=600, height=350, bg='azure3')
+        self.ghetto_canvas = tk.Canvas(self.ctr_mid, width=650, height=400, bg='azure3')
         # self.ghetto_canvas = tk.Canvas(self.ctr_mid, width=540, height=350, bg='azure3')
         self.ghetto_canvas.grid(row=0, column=1, sticky="nsew")
 
@@ -104,13 +119,19 @@ class UIWindow(tk.Tk):
         self.canvas_frame.bind('<Enter>', self._bound_to_mousewheel)
         self.canvas_frame.bind('<Leave>', self._unbound_to_mousewheel)
 
-        # center right
-        self.progressbar = ttk.Progressbar(self.ctr_right, orient="vertical", length=350, mode="determinate")
+        # center
+        self.lbl_record_cb = tk.Label(self.canvas_frame, text='Record', underline=0, bg='azure3')
+        self.lbl_search_entry = tk.Label(self.canvas_frame,
+                                         text='Search multiple words (record if match): podcast concert elvis',
+                                         underline=0, bg='azure3')
+        self.lbl_search_cb = tk.Label(self.canvas_frame, text='Search', bg='azure3')
+        self.lbl_radio_cb = tk.Label(self.canvas_frame, text='Radio', bg='azure3')
+
         # bottom
 
         self.lbl_rec = tk.Label(master=self.btm_frame, bg='azure3', anchor="s")
         self.btn_editor = tk.Button(master=self.btm_frame, text="Radio Editor",
-                                    width=10,  padx=2, pady=1, command=UItextEditor)
+                                    width=10, padx=2, pady=1, command=UItextEditor)
         self.btn_stop = tk.Button(master=self.btm_frame, text="Stop", width=10, padx=2, pady=1, command=self.exit_app)
         self.btn_rec = tk.Button(master=self.btm_frame, text="Record", width=10,
                                  padx=2, pady=1, command=self.list_checked)
@@ -133,7 +154,9 @@ class UIWindow(tk.Tk):
         term.GBase.settings_path = ini_file
         self.entry_ini.delete(0, tk.END)
         self.entry_ini.insert(0, ini_file)
-        self.lbl_info.config(text='Oben links der Knopf ist für die Datei mit den Web Radios.')
+        self.lbl_info.config(text='"Radio List" Starte oben links./ Start upper left. Web Radios.')
+
+        term.GBase.pool.submit(self.language_select)
 
     def on_enter(self, event):
         self.canvas.create_line(0, 225, 2000, 225, fill='orange', width=10, tag="line")
@@ -199,7 +222,6 @@ class UIWindow(tk.Tk):
             os.remove(test_file)
 
             if not self.data_dir_set:
-
                 term.GBase.radio_base_dir = data_folder
                 term.GBase.make_directory(data_folder)
                 self.entry_bbr.delete(0, tk.END)
@@ -220,7 +242,7 @@ class UIWindow(tk.Tk):
     def cb_checked(self):
         is_playlist_server = ''
         for ctr, int_var in enumerate(self.box_list):
-            if int_var.get():     # IntVar not zero==checked
+            if int_var.get():  # IntVar not zero==checked
                 self.lbl_li[ctr].configure(foreground='black')  # <widget>.configure(foreground='black',bg='red')
 
     def cb_search(self):
@@ -235,48 +257,52 @@ class UIWindow(tk.Tk):
 
     def load_settings(self, list_of_widgets, frame):
 
+        self.start_screen = False
         self.print_dir()
         self.box_list = []
         self.search_list = []
-        # remove start screen
-        self.ctr_mid.grid()
-        self.canvas.grid_remove()
-        tk.Label(frame, text='Record', underline=0, bg='azure3').grid(row=0, column=2, sticky="e")
-        tk.Label(frame, text='Search multiple words (record if match): podcast concert elvis', underline=0,
-                 bg='azure3').grid(row=0, column=1, sticky="n")
-        tk.Label(frame, text='Search', bg='azure3').grid(row=0, column=0, sticky="w")
-        tk.Label(frame, text='Radio', bg='azure3').grid(row=0, column=3, sticky="w")
+        self.ctr_mid.grid()  # init scrollbar connected frame
+        self.canvas.grid_remove()  # remove start screen
 
-        term.GBase.pool.submit(self.display_info_text)
-
-        for idx, text in enumerate(list_of_widgets):
-
-            self.box_list.append(tk.IntVar())  # auto var from python PY_VAR0 1 2 for finding check buttons
-            self.search_list.append(tk.IntVar())
-            lbl = tk.Label(frame, text=text, bg='azure3')
-            lbl.grid(row=idx + 1, column=3, sticky="w")
-            self.lbl_li.append(lbl)
-
-            entry = tk.Entry(frame, width=60, bg='azure3')
-            entry.grid(row=idx + 1, column=1, sticky="w")
-
-            self.entry_list.append(entry)
-            tk.Checkbutton(frame, variable=self.search_list[-1],
-                           command=self.cb_search, bg='azure3').grid(row=idx + 1, column=0, sticky='e')
-
-            tk.Checkbutton(frame, variable=self.box_list[-1],
-                           command=self.cb_checked, bg='azure3').grid(row=idx + 1, column=2, sticky='e')
+        self.lbl_record_cb.grid(row=1, column=2, sticky="e")
+        self.lbl_search_entry.grid(row=1, column=1, sticky="n")
+        self.lbl_search_cb.grid(row=1, column=0, sticky="w")
+        self.lbl_radio_cb.grid(row=1, column=3, sticky="w")
 
         # draw the scrollbar
-        ghetto_scroll = tk.Scrollbar(self.ctr_mid, orient=tk.VERTICAL)
-        ghetto_scroll.config(command=self.ghetto_canvas.yview)
-        self.ghetto_canvas.config(yscrollcommand=ghetto_scroll.set)
-        ghetto_scroll.grid(row=0, column=5, sticky="ns")
+        ghetto_scrolly = tk.Scrollbar(self.ctr_mid, orient=tk.VERTICAL)
+        ghetto_scrolly.config(command=self.ghetto_canvas.yview)
+        self.ghetto_canvas.config(yscrollcommand=ghetto_scrolly.set)
+        ghetto_scrolly.grid(row=0, column=5, sticky="ns")
+
+        ghetto_scrollx = tk.Scrollbar(self.ctr_mid, orient=tk.HORIZONTAL)
+        ghetto_scrollx.config(command=self.ghetto_canvas.xview)
+        self.ghetto_canvas.config(xscrollcommand=ghetto_scrollx.set)
+        ghetto_scrollx.grid(row=1, column=1, sticky="ew")
 
         self.canvas_frame.bind("<Configure>", self.update_scrollregion)
 
+        for idx, text in enumerate(list_of_widgets):
+            self.box_list.append(tk.IntVar())  # auto var from python PY_VAR0 1 2 for finding check buttons
+            self.search_list.append(tk.IntVar())
+            lbl = tk.Label(frame, text=text, bg='azure3')
+            lbl.grid(row=idx + 2, column=3, sticky="w")
+            self.lbl_li.append(lbl)
+
+            entry = tk.Entry(frame, width=60, bg='azure3')
+            entry.grid(row=idx + 2, column=1, sticky="w")
+
+            self.entry_list.append(entry)
+            tk.Checkbutton(frame, variable=self.search_list[-1],
+                           command=self.cb_search, bg='azure3').grid(row=idx + 2, column=0, sticky='e')
+
+            tk.Checkbutton(frame, variable=self.box_list[-1],
+                           command=self.cb_checked, bg='azure3').grid(row=idx + 2, column=2, sticky='e')
+
     def list_checked(self):
 
+        term.GBase.pool.submit(self.display_info_text)
+
         for ctr, int_var in enumerate(self.box_list):
             # all checked rec.
             if int_var.get():
@@ -296,8 +322,11 @@ class UIWindow(tk.Tk):
                     self.lbl_info.config(text=self.entry_list[ctr].get())
 
                 # PLAYLIST is handled in add_server_to..UI, bit diff. than in terminal
-                self.add_server_to_data_base_ui(str(self.lbl_li[ctr].cget("text")),
-                                                str(term.GIni.find_ini_file(self.lbl_li[ctr].cget("text"))))
+                # self.add_server_to_data_base_ui(str(self.lbl_li[ctr].cget("text")),
+                #                                str(term.GIni.find_ini_file(self.lbl_li[ctr].cget("text"))))
+
+                term.add_server_to_data_base_auto(str(self.lbl_li[ctr].cget("text")),
+                                                  str(term.GIni.find_ini_file(self.lbl_li[ctr].cget("text"))))
 
         self.btn_rec = tk.Button(master=self.btm_frame, text="Record", width=10, state="disabled")
         self.btn_rec.grid(row=0, column=3, sticky='w')
@@ -308,6 +337,7 @@ class UIWindow(tk.Tk):
         # term.step2_test_stream_server(term.GIni.ini_keys) not yet
 
         for key in term.GIni.ini_keys:
+            # term.GBase.pool.submit(term.record, key)
             term.GBase.pool.submit(self.start_records, key)
 
         term.GBase.pool.submit(self.display_title)
@@ -323,7 +353,7 @@ class UIWindow(tk.Tk):
 
         # ----- no del -- term.GRecorder.thread_pull_song_name(url, key, None, None)
         stream_suffix = term.GIni.srv_param_dict[key + '_file']
-        term.GIni.song_dict[key] = str('_no-name-record_no_split_')  # init the dict for this thread
+        term.GRecorder.current_song_dict[key] = '_no-name-record_no_split_'  # init the dict for this thread
         term.GIni.start_stop_recording[key] = 'start'
         term.GIni.start_stop_recording[key + '_adv'] = 'start_from_here'
 
@@ -334,9 +364,11 @@ class UIWindow(tk.Tk):
         url = term.GIni.ini_keys[key]
         print(f'{key} {url}')
         dir_save = term.GBase.radio_base_dir + '//' + key
-        term.GBase.pool.submit(term.GRecorder.record_songs, url, dir_save, stream_suffix, key, None)
-        term.GRecorder.path_to_song_dict = term.GIni.song_dict
-        term.GBase.pool.submit(term.GRecorder.thread_pull_song_name, url, key, None, None)
+        # term.GRecorder.path_to_song_dict = term.GIni.song_dict
+        # term.GBase.pool.submit(term.GRecorder.record_songs, url, dir_save, stream_suffix, key, None)
+        term.GBase.pool.submit(term.GRecorder.thread_pull_song_name, url, key)
+        term.GBase.pool.submit(term.GRecorder.ghetto_recorder_head, dir_save, stream_suffix, key)
+        term.GBase.pool.submit(term.GRecorder.ghetto_recorder_tail, url, key, dir_save)
 
     def display_title(self):
 
@@ -346,7 +378,7 @@ class UIWindow(tk.Tk):
                     radio = str(self.lbl_li[idx].cget("text"))
                     self.entry_list[idx].delete(0, tk.END)
                     try:
-                        title = term.GRecorder.path_to_song_dict[radio]
+                        title = term.GRecorder.current_song_dict[radio]
                         self.entry_list[idx].insert(0, title)
                     except Exception as ex:
                         print(ex)
@@ -358,6 +390,7 @@ class UIWindow(tk.Tk):
 
     @staticmethod
     def add_server_to_data_base_ui(str_key, str_val):
+        # sense of mirroring from term module is using "UIUtils.playlist_m3u(str_val) def" for auto select server
         is_playlist_server = ''
         term.GIni.ini_keys[str_key] = str_val  # append url to dictionary as value
         term.GBase.make_directory(term.GBase.radio_base_dir + '//' + str_key)
@@ -367,12 +400,11 @@ class UIWindow(tk.Tk):
             is_playlist_server = UIUtils.playlist_m3u(str_val)
         if not is_playlist_server == '':  # update dictionary with new url
             term.GIni.ini_keys[str_key] = is_playlist_server  # append dictionary, test if it is alive
-            if not term.GNet.is_server_meta_stream(term.GIni.ini_keys[str_key]):
+            if not term.GNet.is_server_alive(term.GIni.ini_keys[str_key], str_key):
                 print('   --> playlist_server server failed, no recording')
                 del term.GIni.ini_keys[str_key]
-        if not term.GNet.is_server_meta_stream(term.GIni.ini_keys[str_key]):  # first time internet access, response code
-            # delete key from dict, return
-            del term.GIni.ini_keys[str_key]
+        # can not del
+        term.GNet.is_server_alive(term.GIni.ini_keys[str_key], str_key)  # delete key from dict in terminal module
 
     def timer(self, time_left):
         combo_time = 0
@@ -391,7 +423,7 @@ class UIWindow(tk.Tk):
                 break
 
         term.GBase.exit_app = True
-        sleep(term.GBase.sleeper + 1)  # threads sleep too, time for exit
+        sleep(term.GBase.sleeper + 1)  # threads sleep too, give time for exit, reset exit_app
         term.GBase.exit_app = False
         self.btn_rec = tk.Button(master=self.btm_frame, text="Record", width=10, command=self.list_checked)
         self.btn_rec.grid(row=0, column=3, sticky='w')
@@ -405,60 +437,126 @@ class UIWindow(tk.Tk):
         self.update_idletasks()
         sleep(1)
 
-    def display_info_text(self):
-
-        while not term.GBase.exit_app:
-            if self.search_started or self.record_started:
-                self.lbl_info.config(text=' ')
-                break
-            for line in UIUtils.info_ger:
-                self.lbl_info.config(text=line)
-                for _ in range(4):
-                    if self.search_started or self.record_started:
-                        self.lbl_info.config(text=' ')
-                        break
-                    sleep(1)
-
-            for line in UIUtils.info_eng:
-                self.lbl_info.config(text=line)
-                for _ in range(4):
-                    if self.search_started or self.record_started:
-                        self.lbl_info.config(text=' ')
-                        break
-                    sleep(1)
-
     def update_scrollregion(self, event):
         self.ghetto_canvas.configure(scrollregion=self.ghetto_canvas.bbox("all"))
 
+    def language_select(self):
 
-class UIUtils(UIWindow):
+        while not term.GBase.exit_app:
 
+            lang = self.combo_lang.get()
+            gl = GhettoLanguage()
+            gl.process_switch_lang(lang)
+
+            for sec in range(2):
+                sleep(1)
+                if term.GBase.exit_app:
+                    break
+
+    def display_info_text(self):
+
+        while not term.GBase.exit_app:
+
+            lang = uiw.combo_lang.get()
+
+            if lang == 'eng':
+                self.list_e = GhettoLanguage.info_eng
+            if lang == 'deutsch':
+                self.list_e = GhettoLanguage.info_ger
+
+            for line in self.list_e:
+
+                if self.record_started:
+                    uiw.lbl_info.config(text=line)
+
+                for _ in range(4):
+                    if not term.GBase.exit_app:
+                        sleep(1)
+
+
+class GhettoLanguage(UIWindow):
     info_ger = [
-        'Die Zeilen in der Mitte sind für Suchbegriffe da.',
-        'Dein Lieblingslied im Radio gehört? Suche es.',
-        'Zuerst im linken Kasten den Haken setzen. "Search"',
-        'Worte wie: Elvis Anthrax Heino Beton Kammermusik.',
-        'Es ist egal, ob das Wort GROSS oder klein geschrieben ist.',
-        'Das Radio spielt den Titel mit dem Wort, Aufnahme startet.',
-        'Bei Titelwechseln kann noch ein Teil des folgenden',
-        'Titels aufgenommen werden. Einfach löschen.',
-        '"Timer" oben rechts, keine Zeit Stop zu drücken?',
-        'Der Timer ist die Eieruhr. Nur in Stunden. Fertig! :)',
-        'Die Uhr kann man jederzeit ändern. Viel Spaß!',
+        ' Die Zeilen in der Mitte sind für Suchbegriffe da.',
+        ' Dein Lieblingslied im Radio gehört? Suche es.',
+        ' Zuerst in einem linken Kasten den Haken setzen. "Suche"',
+        ' Worte wie: Elvis Anthrax Heino Beton Kammermusik reinschreiben.',
+        ' Es ist egal, ob das Wort GROSS oder klein geschrieben ist.',
+        ' Das Radio spielt den Titel mit dem Wort, die Aufnahme startet und endet dann.',
+        ' Bei Titelwechseln kann noch ein Teil des folgenden',
+        ' Titels aufgenommen werden. Einfach löschen.',
+        ' Die "Uhr" oben rechts, falls mal keine Zeit da ist "Stop" zu drücken.',
+        ' Der Uhr ist eine wie rinr Eieruhr. Nur in Stunden. Fertig! :)',
+        ' Die Uhr kann man jederzeit ändern. Viel Spaß!',
     ]
 
     info_eng = [
-        'The lines in the middle area are used for searching phrases.',
-        'Your favorite song on air? Search the title or artist.',
-        'Please activate the corresponding box on the left. "Search"',
-        'Phrases like: Elvis Anthrax Heino concrete chamber music.',
-        'There is no rule for writing the words UPPER or lower case.',
-        'Radio station is playing a title with a search phrase! Record!',
-        'A "Timer" in the upper right corner. If you do not like ',
-        'pressing the "Stop" button yourself. One can change the value',
+        ' The lines in the middle area are used for searching phrases.',
+        ' Your favorite song on air? Search the title or artist.',
+        ' Please activate the corresponding box on the left. "Search"',
+        ' Phrases like: Elvis Anthrax Heino concrete chamber music.',
+        ' There is no rule for writing the words UPPER or lower case.',
+        ' Radio station is playing a title with a search phrase! Record!',
+        ' A "Timer" in the upper right corner. If you do not like ',
+        ' pressing the "Stop" button yourself. One can change the value',
         ' every time. Have fun!'
     ]
 
+    dict_eng = {'button-edit': 'Radio Editor',
+                'button_ini': 'Radio List',
+                'button_bbr': 'Save to ...',
+                'entry_radio_dir': 'place to create a bunch of folders',
+                'label_timer': 'Timer',
+                'label_change_lang': 'Language',
+                'label_bottom_info_start': ' Start upper left with "Radio List" and open "settings.ini" file, '
+                                           'bottom left one can edit the list."',
+                'label_bottom_info': ' Server down? Often under maintenance.',
+                'label_bottom_info_else': ' xxxxxxxxxxexxxxxxxxx.',
+                'label_search': 'Search',
+                'entry_search_info': 'artist song (multi) (record if match): Elvis Ghetto concert'}
+
+    dict_ger = {'button-edit': 'Radio Editor',
+                'button_ini': 'Radio Liste',
+                'button_bbr': 'Speichern',
+                'entry_radio_dir': 'Aufnahme, Verzeichnis für die Radio Stationen',
+                'label_timer': 'Uhr',
+                'label_change_lang': 'Sprache',
+                'label_bottom_info_start': ' Beginne oben links mit "Radio Liste", öffne "settings.ini" Datei. '
+                                           'Unten links kann man die Datei ändern."',
+                'label_bottom_info': ' Server nicht erreichbar? Oft nur Wartungsarbeiten.',
+                'label_bottom_info_else': ' xxxxxxxxxxdxxxxxxxxx.',
+                'label_search': 'Suche',
+                'entry_search_info': 'Interpret Titel (mehrere), Treffer/Aufnahme: Elvis Ghetto Beton'}
+
+    def __init__(self):
+        super().__init__()
+        self.list_e = []
+
+    def process_switch_lang(self, arg):
+        dictionary = {}
+        if arg == 'eng':
+            dictionary = self.dict_eng
+        if arg == 'deutsch':
+            dictionary = self.dict_ger
+
+        uiw.btn_editor.configure(text=dictionary['button-edit'])
+        uiw.btn_ini.configure(text=dictionary['button_ini'])
+        uiw.btn_browse.configure(text=dictionary['button_bbr'])
+        uiw.entry_bbr.delete(0, tk.END)
+        uiw.entry_bbr.insert(0, dictionary['entry_radio_dir'])
+        uiw.lbl_timer.configure(text=dictionary['label_timer'])
+        uiw.lbl_lang.configure(text=dictionary['label_change_lang'])
+        if uiw.start_screen:
+            uiw.lbl_info.configure(text=dictionary['label_bottom_info_start'])
+        if not uiw.start_screen:
+            if not uiw.record_started:
+                uiw.lbl_info.configure(text=dictionary['label_bottom_info'])
+
+        uiw.lbl_search_cb.configure(text=dictionary['label_search'])
+        uiw.lbl_search_entry.configure(text=dictionary['entry_search_info'])
+
+
+class UIUtils(UIWindow):
+
     def __init__(self, radio_dir=None, settings_path=None):
         super().__init__()
 
@@ -497,7 +595,3 @@ class UIUtils(UIWindow):
 if __name__ == "__main__":
     uiw = UIWindow()
     uiw.mainloop()
-
-
-
-
